Documentation
¶
Overview ¶
Tool to parse freelancer configs
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DiscoveryConfig ¶ added in v0.44.0
type DiscoveryConfig struct {
Techcompat *techcompat.Config
Prices *discoprices.Config
BaseRecipeItems *base_recipe_items.Config
LatestPatch autopatcher.Patch
PlayercntlRephacks *playercntl_rephacks.Config
}
type MappedConfigs ¶
type MappedConfigs struct {
FreelancerINI *exe_mapped.Config
Universe_config *universe_mapped.Config
Systems *systems_mapped.Config
Market *market_mapped.Config
Equip *equip_mapped.Config
Goods *equipment_mapped.Config
Shiparch *ship_mapped.Config
InfocardmapINI *interface_mapped.Config
Infocards *infocard.Config
InitialWorld *initialworld.Config
Empathy *empathy_mapped.Config
MBases *mbases_mapped.Config
Consts *const_mapped.Config
WeaponMods *weaponmoddb.Config
NpcRankToDiff *npcranktodiff.Config
DiffToMoney *diff2money.Config
FactionProps *faction_props_mapped.Config
NpcShips *npc_ships.Config
Solararch *solar_mapped.Config
Discovery *DiscoveryConfig
Overrides overrides.Overrides
}
func NewMappedConfigs ¶
func NewMappedConfigs() *MappedConfigs
func TestFixtureConfigs ¶
func TestFixtureConfigs() *MappedConfigs
func (*MappedConfigs) Read ¶
func (p *MappedConfigs) Read(file1path utils_types.FilePath) *MappedConfigs
func (*MappedConfigs) Write ¶
func (p *MappedConfigs) Write(is_dry_run IsDruRun)
Directories
¶
| Path | Synopsis |
|---|---|
|
data_mapped
This package is equal to DATA folder present in Freelancer Discovery.
|
This package is equal to DATA folder present in Freelancer Discovery. |
|
data_mapped/universe_mapped
parse universe.ini
|
parse universe.ini |
|
exe_mapped/go-binary-pack
Package binary_pack performs conversions between some Go values represented as byte slices.
|
Package binary_pack performs conversions between some Go values represented as byte slices. |
|
parserutils
|
|
|
filefind
Package with reusable code for discovery of files and other reusable stuff like universal ini reader
|
Package with reusable code for discovery of files and other reusable stuff like universal ini reader |
|
inireader
Okay we need to create syntax.
|
Okay we need to create syntax. |
|
inireader/experiment
command
|
|
|
semantic
ORM mapper for Freelancer ini reader.
|
ORM mapper for Freelancer ini reader. |
Click to show internal directories.
Click to hide internal directories.